Stan Math Library: stan/math/prim/scal/prob/logistic_rng.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

logistic_rng.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_SCAL_PROB_LOGISTIC_RNG_HPP
2 #define STAN_MATH_PRIM_SCAL_PROB_LOGISTIC_RNG_HPP
3
4 #include <stan/math/prim/scal/err/check_consistent_sizes.hpp>
5 #include <stan/math/prim/scal/err/check_finite.hpp>
6 #include <stan/math/prim/scal/err/check_not_nan.hpp>
7 #include <stan/math/prim/scal/err/check_positive_finite.hpp>
8 #include <stan/math/prim/scal/fun/constants.hpp>
9 #include <stan/math/prim/scal/fun/value_of.hpp>
10 #include <stan/math/prim/scal/fun/log1p.hpp>
11 #include <stan/math/prim/scal/meta/length.hpp>
12 #include <stan/math/prim/scal/meta/VectorView.hpp>
13 #include <stan/math/prim/scal/meta/VectorBuilder.hpp>
14 #include <stan/math/prim/scal/meta/return_type.hpp>
15 #include <stan/math/prim/scal/meta/include_summand.hpp>
16 #include <boost/random/exponential_distribution.hpp>
17 #include <boost/random/variate_generator.hpp>
18
19 namespace stan {
20 namespace math {
21
22 template <class RNG>
23 inline double
24 logistic_rng(const double mu,
25 const double sigma,
26 RNG& rng) {
27 using boost::variate_generator;
28 using boost::random::exponential_distribution;
29
30 static const char* function("stan::math::logistic_rng");
31
32 using stan::math::check_positive_finite;
33 using stan::math::check_finite;
34
35 check_finite(function, "Location parameter", mu);
36 check_positive_finite(function, "Scale parameter", sigma);
37
38 variate_generator<RNG&, exponential_distribution<> >
39 exp_rng(rng, exponential_distribution<>(1));
40 return mu - sigma * std::log(exp_rng() / exp_rng());
41 }
42 }
43 }
44 #endif
check_not_nan.hpp
check_positive_finite.hpp
stan
Definition: log_sum_exp.hpp:8
stan::math::log
fvar< T > log(const fvar< T > &x)
Definition: log.hpp:15
return_type.hpp
include_summand.hpp
VectorView.hpp
stan::math::logistic_rng
double logistic_rng(const double mu, const double sigma, RNG &rng)
Definition: logistic_rng.hpp:24
VectorBuilder.hpp
length.hpp
stan::math::check_finite
bool check_finite(const char *function, const char *name, const T_y &y)
Return true if y is finite.
Definition: check_finite.hpp:62
constants.hpp
check_finite.hpp
log1p.hpp
value_of.hpp
check_consistent_sizes.hpp
stan::math::check_positive_finite
bool check_positive_finite(const char *function, const char *name, const T_y &y)
Return true if y is positive and finite.
Definition: check_positive_finite.hpp:28

[ Stan Home Page ] © 2011–2016, Stan Development Team.